@@ -2,40 +2,48 @@ package Net::Launchpad;
 BEGIN {
   $Net::Launchpad::AUTHORITY = 'cpan:ADAMJS';
 }
-$Net::Launchpad::VERSION = '1.0.4';
+$Net::Launchpad::VERSION = '1.0.5';
 # ABSTRACT: Launchpad.net Authentication
 
-use Mojo::Base -base;
+use Moose;
+use Function::Parameters;
 use Mojo::UserAgent;
-use Mojo::JSON;
 use Mojo::URL;
 use Mojo::Parameters;
-use Function::Parameters {
-    func   => 'function_strict',
-    method => 'method_strict'
-};
+use Data::Dumper::Concise;
+use namespace::autoclean;
 
-has 'staging' => 0;
-has 'consumer_key';
-has 'callback_uri';
-has 'json' => method { Mojo::JSON->new };
 
-has 'ua' => method {
-    my $ua = Mojo::UserAgent->new;
-    $ua->transactor->name("Net::Salesforce");
-    return $ua;
-};
+has staging => (is => 'ro', isa => 'Int', default => 0);
+has consumer_key => (is => 'ro', isa => 'Str');
+has callback_uri => (is => 'ro', isa => 'Str');
 
-has 'nonce' => method {
-    my @a     = ('A' .. 'Z', 'a' .. 'z', 0 .. 9);
+has ua => (
+    is      => 'ro',
+    isa     => 'Mojo::UserAgent',
+    default => method {
+        my $ua = Mojo::UserAgent->new;
+        $ua->transactor->name("Net::Salesforce");
+        return $ua;
+    }
+);
+
+
+has nonce => (is => 'ro', isa => 'Str', builder => '_build_nonce');
+
+method _build_nonce {
+    my @a = ('A' .. 'Z', 'a' .. 'z', 0 .. 9);
     my $nonce = '';
     for (0 .. 31) {
         $nonce .= $a[rand(scalar(@a))];
     }
     return $nonce;
-};
+}
 
-has 'params' => method {
+
+has params => (is => 'rw', isa => 'HashRef', builder => '_build_params');
+
+method _build_params {
     return {
         oauth_callback         => $self->callback_uri,
         oauth_consumer_key     => $self->consumer_key,
@@ -47,7 +55,7 @@ has 'params' => method {
         oauth_timestamp        => time,
         oauth_nonce            => $self->nonce
     };
-};
+}
 
 method api_host {
     return Mojo::URL->new('https://launchpad.net/') unless $self->staging;
@@ -94,9 +102,11 @@ method access_token($token, $secret) {
         $self->access_token_path->to_string => form => $self->params);
     die $tx->res->body unless $tx->success;
     my $params = Mojo::Parameters->new($tx->res->body);
+    print Dumper($params);
     return ($params->param('oauth_token'), $params->param('oauth_token_secret'));
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -111,7 +121,7 @@ Net::Launchpad - Launchpad.net Authentication
 
 =head1 VERSION
 
-version 1.0.4
+version 1.0.5
 
 =head1 ATTRIBUTES
 
